@@ -15,9 +15,6 @@
 #include "metawear/platform/btle_connection.h"
 #include "metawear/platform/dllmarker.h"
 
-/** Constant signifying a module is not available */
-const int32_t MBL_MW_MODULE_TYPE_NA = -1;
-
 #ifdef __cplusplus
 extern "C" {
 #endif
