@@ -10,7 +10,7 @@
 #include "metawear/core/cpp/datasignal_private.h"
 #include "metawear/sensor/accelerometer_bosch.h"
 #include "metawear/sensor/cpp/accelerometer_bosch_private.h"
-#include "metawear/sensor/cpp/gyro_bmi160_private.h"
+#include "metawear/sensor/cpp/gyro_bosch_private.h"
 #include "metawear/core/cpp/logging_private.h"
 #include "metawear/processor/cpp/dataprocessor_config.h"
 #include "metawear/processor/cpp/dataprocessor_private.h"
@@ -122,7 +122,7 @@ static MblMwData* convert_to_bosch_acceleration_unsigned_single_axis(bool log_da
     CREATE_MESSAGE(MBL_MW_DT_ID_FLOAT);
 }
 
-static MblMwData* convert_to_bmi160_rotation(bool log_data, const MblMwDataSignal* signal, const uint8_t *response, uint8_t len) {
+static MblMwData* convert_to_bosch_rotation(bool log_data, const MblMwDataSignal* signal, const uint8_t *response, uint8_t len) {
     CartesianShort unscaled;
     memcpy(&unscaled, response, sizeof(unscaled));
 
@@ -136,7 +136,7 @@ static MblMwData* convert_to_bmi160_rotation(bool log_data, const MblMwDataSigna
     CREATE_MESSAGE(MBL_MW_DT_ID_CARTESIAN_FLOAT);
 }
 
-static MblMwData* convert_to_bmi160_rotation_single_axis(bool log_data, const MblMwDataSignal* signal, const uint8_t *response, uint8_t len) {
+static MblMwData* convert_to_bosch_rotation_single_axis(bool log_data, const MblMwDataSignal* signal, const uint8_t *response, uint8_t len) {
     int32_t unscaled;
     CAST_INT32(unscaled)
 
@@ -146,7 +146,7 @@ static MblMwData* convert_to_bmi160_rotation_single_axis(bool log_data, const Mb
     CREATE_MESSAGE(MBL_MW_DT_ID_FLOAT);
 }
 
-static MblMwData* convert_to_bmi160_rotation_unsigned_single_axis(bool log_data, const MblMwDataSignal* signal, const uint8_t *response, uint8_t len) {
+static MblMwData* convert_to_bosch_rotation_unsigned_single_axis(bool log_data, const MblMwDataSignal* signal, const uint8_t *response, uint8_t len) {
     uint32_t unscaled= 0;
     CAST_UINT32(unscaled)
 
@@ -202,6 +202,28 @@ static MblMwData* convert_to_bosch_any_motion(bool log_data, const MblMwDataSign
     CREATE_MESSAGE(MBL_MW_DT_ID_BOSCH_ANY_MOTION);
 }
 
+static MblMwData* convert_to_bmi270_gesture(bool log_data, const MblMwDataSignal* signal, const uint8_t *response, uint8_t len) {
+    MblMwBoschGestureType *value= (MblMwBoschGestureType*) malloc(sizeof(MblMwBoschGestureType));
+
+    value->type = response[0] & 0x03;
+    
+    uint32_t temp = response[0];
+    temp = temp >> 2;
+    value->gesture_code = temp;
+
+    CREATE_MESSAGE(MBL_MW_DT_ID_BOSCH_GESTURE);
+}
+
+static MblMwData* convert_to_bmi270_activity(bool log_data, const MblMwDataSignal* signal, const uint8_t *response, uint8_t len) {
+    uint32_t temp = response[0];
+    temp = temp >> 1;
+    
+    uint32_t *value= (uint32_t*) calloc(1, sizeof(uint32_t));
+    memcpy(value, &temp, sizeof(uint32_t));
+
+    CREATE_MESSAGE(MBL_MW_DT_ID_UINT32);
+}
+
 CONVERT_TO_FLOAT(convert_to_temperature, int32_t, TEMPERATURE_SCALE)
 
 CONVERT_TO_FLOAT(convert_to_mma8452q_acceleration_single_axis, int32_t, MMA8452Q_ACC_SCALE)
@@ -363,9 +385,9 @@ unordered_map<DataInterpreter, FnBoolDataSignalByteArray> data_response_converte
     { DataInterpreter::TEMPERATURE , convert_to_temperature },
     { DataInterpreter::BOSCH_PRESSURE , convert_to_bmp280_pressure },
     { DataInterpreter::BOSCH_ALTITUDE , convert_to_bmp280_altitude },
-    { DataInterpreter::BMI160_ROTATION , convert_to_bmi160_rotation },
-    { DataInterpreter::BMI160_ROTATION_SINGLE_AXIS , convert_to_bmi160_rotation_single_axis },
-    { DataInterpreter::BMI160_ROTATION_UNSIGNED_SINGLE_AXIS , convert_to_bmi160_rotation_unsigned_single_axis },
+    { DataInterpreter::BOSCH_ROTATION , convert_to_bosch_rotation },
+    { DataInterpreter::BOSCH_ROTATION_SINGLE_AXIS , convert_to_bosch_rotation_single_axis },
+    { DataInterpreter::BOSCH_ROTATION_UNSIGNED_SINGLE_AXIS , convert_to_bosch_rotation_unsigned_single_axis },
     { DataInterpreter::BOSCH_ACCELERATION , convert_to_bosch_acceleration },
     { DataInterpreter::BOSCH_ACCELERATION_SINGLE_AXIS , convert_to_bosch_acceleration_single_axis },
     { DataInterpreter::BOSCH_ACCELERATION_UNSIGNED_SINGLE_AXIS , convert_to_bosch_acceleration_unsigned_single_axis },
@@ -394,7 +416,9 @@ unordered_map<DataInterpreter, FnBoolDataSignalByteArray> data_response_converte
     { DataInterpreter::BOSCH_ANY_MOTION, convert_to_bosch_any_motion },
     { DataInterpreter::SENSOR_FUSION_CALIB_STATE, convert_to_calibration_state },
     { DataInterpreter::FUSED_DATA, convert_to_fused },
-    { DataInterpreter::BOSCH_TAP, convert_to_bosch_tap }
+    { DataInterpreter::BOSCH_TAP, convert_to_bosch_tap },
+    { DataInterpreter::BMI270_GESTURE , convert_to_bmi270_gesture },
+    { DataInterpreter::BMI270_ACTIVITY , convert_to_bmi270_activity }
 };
 
 static float bosch_acc_to_firmware(const MblMwDataSignal* signal, float value) {
@@ -438,7 +462,7 @@ unordered_map<FirmwareConverter, FnDataSignalFloat> number_to_firmware_converter
     { FirmwareConverter::BME280_HUMIDITY , bme280_humidity_to_firmware },
     { FirmwareConverter::BOSCH_ACCELERATION , bosch_acc_to_firmware },
     { FirmwareConverter::BOSCH_BAROMETER , bosch_baro_to_firmware },
-    { FirmwareConverter::BMI160_ROTATION , bosch_gyro_to_firmware },
+    { FirmwareConverter::BOSCH_ROTATION , bosch_gyro_to_firmware },
     { FirmwareConverter::MMA8452Q_ACCELERATION , mma8452q_to_firmware},
     { FirmwareConverter::TEMPERATURE , temp_to_firmware},
     { FirmwareConverter::Q16_16_FIXED_POINT , q16_16_fixed_point_to_firmware},
@@ -469,4 +493,4 @@ void free_data(const MblMwDataSignal* signal, MblMwData* data) {
     }
     free(data->value);
     free(data);
-}
\ No newline at end of file
+}
