@@ -36,7 +36,7 @@
 #include "metawear/processor/cpp/dataprocessor_private.h"
 
 #include "metawear/sensor/accelerometer.h"
-#include "metawear/sensor/gyro_bmi160.h"
+#include "metawear/sensor/gyro_bosch.h"
 #include "metawear/sensor/sensor_fusion.h"
 
 #include "metawear/sensor/cpp/accelerometer_private.h"
@@ -45,7 +45,7 @@
 #include "metawear/sensor/cpp/colordetector_tcs34725_private.h"
 #include "metawear/sensor/cpp/gpio_private.h"
 #include "metawear/sensor/cpp/gpio_register.h"
-#include "metawear/sensor/cpp/gyro_bmi160_private.h"
+#include "metawear/sensor/cpp/gyro_bosch_private.h"
 #include "metawear/sensor/cpp/humidity_bme280_private.h"
 #include "metawear/sensor/cpp/magnetometer_bmm150_private.h"
 #include "metawear/sensor/cpp/multichanneltemperature_private.h"
@@ -59,6 +59,8 @@
 using namespace std;
 using namespace std::chrono;
 
+/** Constant signifying a module is not available */
+const int32_t MBL_MW_MODULE_TYPE_NA = -1;
 const uint8_t CARTESIAN_FLOAT_SIZE= 6;
 const uint16_t MAX_TIME_PER_RESPONSE= 4000;
 
@@ -589,11 +591,19 @@ MblMwModel mbl_mw_metawearboard_get_model(const MblMwMetaWearBoard* board) {
         return MBL_MW_MODEL_METATRACKER;
     }
     if (board->module_number == "5") {
-        return MBL_MW_MODEL_METAMOTION_R;
+        if (mbl_mw_metawearboard_lookup_module(board, MBL_MW_MODULE_AMBIENT_LIGHT) != MBL_MW_MODULE_TYPE_NA) {
+            return MBL_MW_MODEL_METAMOTION_R;
+        } else {
+            return MBL_MW_MODEL_METAMOTION_RL;
+        }
     }
     if (board->module_number == "6") {
         return MBL_MW_MODEL_METAMOTION_C;
     }
+    if (board->module_number == "8") {
+        return MBL_MW_MODEL_METAMOTION_S;
+    }
+
 
     return MBL_MW_MODEL_NA;
 }
@@ -610,7 +620,9 @@ const char * MODEL_NAMES[] = {
     "MetaHealth",
     "MetaTracker",
     "MetaMotion R",
-    "MetaMotion C"
+    "MetaMotion RL",
+    "MetaMotion C",
+    "MetaMotion S"
 };
 const char* mbl_mw_metawearboard_get_model_name(const MblMwMetaWearBoard* board) {
     return MODEL_NAMES[mbl_mw_metawearboard_get_model(board) + 1];
